# SFIBlues Metocean library

Illustrates fetching metocean data from different sources. 

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install simapy.

```bash
pip install bluesmet
```

## Development

Necessary dependencies installed using

pip install -r requirements.txt

Development dependencies installed using

pip install -r requirements-dev.txt

Developed for use with the  [SFI Blues Metocean portal](https://sfiblues-portal.azurewebsites.net/met)

Find example usage [here](https://github.com/SINTEF/blues-metocean-lib-examples)
